﻿using System;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using TypedClientHttpClientFactoryReturningError.Models;
using TypedClientHttpClientFactoryReturningError.TypedClients;

namespace TypedClientHttpClientFactoryReturningError.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class OrderController : ControllerBase
    {
        private readonly InvoiceClient _invoiceClient;

        public OrderController(InvoiceClient invoiceClient)
        {
            _invoiceClient = invoiceClient;
        }

        [HttpGet("{orderId}")]
        public async Task<ActionResult> Get(int orderId)
        {
            // Pretend to load the order from the db. 
            Order order = new Order { OrderId = orderId, OrderDate = new DateTime(2018, 6, 14), CustomerId = 1001 };

            var invoiceResponse = await _invoiceClient.GetInvoice(orderId);

            if (invoiceResponse.Content != null)
            {
                order.Cost = invoiceResponse.Content.Cost;
                return Ok(order);
            }
            return StatusCode((int)invoiceResponse.HttpStatusCode, invoiceResponse.Message);
        }
    }
}
